@@ -43,7 +43,7 @@ class Zeroconf:
         self.port = port # listening port that gets announced
         self.username = name
         self.host = host
-        self.txt = pybonjour.TXTRecord()                # service data
+        self.txt = {}  # service data
 
         # XXX these CBs should be set to None when we destroy the object
         # (go offline), because they create a circular reference
@@ -245,7 +245,7 @@ class Zeroconf:
         txt = {}
 
         #remove empty keys
-        for key, val in self.txt:
+        for key, val in self.txt.iteritems():
             if val:
                 txt[key] = val
 
@@ -259,13 +259,12 @@ class Zeroconf:
         else:
             txt['status'] = 'avail'
 
-        self.txt = pybonjour.TXTRecord(txt, strict=True)
         try:
             self.service_sdRef = pybonjour.DNSServiceRegister(
                 name=self.name,
                 regtype=self.stype,
                 port=self.port,
-                txtRecord=self.txt,
+                txtRecord=pybonjour.TXTRecord(txt),
                 callBack=self.service_added_callback)
 
             log.info('Publishing service %s of type %s' % (self.name, self.stype))
