@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 ## src/message_window.py
 ##
-## Copyright (C) 2003-2014 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2003-2017 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2005-2008 Travis Shirk <travis AT pobox.com>
 ##                         Nikos Kouremenos <kourem AT gmail.com>
 ## Copyright (C) 2006 Geobert Quach <geobert AT gmail.com>
@@ -311,7 +311,8 @@ class MessageWindow(object):
         # NOTE: we do not call set_control_active(True) since we don't know
         # whether the tab is the active one.
         self.show_title()
-        gobject.timeout_add(500, control.msg_textview.grab_focus)
+        if self.get_num_controls() == 1:
+            gobject.timeout_add(500, control.msg_textview.grab_focus)
 
     def on_tab_eventbox_button_press_event(self, widget, event, child):
         if event.button == 3: # right click
@@ -617,7 +618,10 @@ class MessageWindow(object):
             ctrl.allow_shutdown(method, on_yes, on_no, on_minimize)
 
     def check_tabs(self):
-        if self.get_num_controls() == 0:
+        if self.parent_paned:
+            # Do nothing in single window mode
+            pass
+        elif self.get_num_controls() == 0:
             # These are not called when the window is destroyed like this, fake it
             gajim.interface.msg_win_mgr._on_window_delete(self.window, None)
             gajim.interface.msg_win_mgr._on_window_destroy(self.window)
@@ -993,16 +997,16 @@ class MessageWindowMgr(gobject.GObject):
         """
         Resizes window according to config settings
         """
+        hpaned = gajim.config.get('roster_hpaned_position')
         if self.mode in (self.ONE_MSG_WINDOW_ALWAYS,
                         self.ONE_MSG_WINDOW_ALWAYS_WITH_ROSTER):
             size = (gajim.config.get('msgwin-width'),
                     gajim.config.get('msgwin-height'))
             if self.mode == self.ONE_MSG_WINDOW_ALWAYS_WITH_ROSTER:
-                parent_size = win.window.get_size()
                 # Need to add the size of the now visible paned handle, otherwise
                 # the saved width of the message window decreases by this amount
                 handle_size = win.parent_paned.style_get_property('handle-size')
-                size = (parent_size[0] + size[0] + handle_size, size[1])
+                size = (hpaned + size[0] + handle_size, size[1])
         elif self.mode == self.ONE_MSG_WINDOW_PERACCT:
             size = (gajim.config.get_per('accounts', acct, 'msgwin-width'),
                     gajim.config.get_per('accounts', acct, 'msgwin-height'))
@@ -1016,7 +1020,7 @@ class MessageWindowMgr(gobject.GObject):
             return
         win.resize(size[0], size[1])
         if win.parent_paned:
-            win.parent_paned.set_position(gajim.config.get('roster_hpaned_position'))
+            win.parent_paned.set_position(hpaned)
 
     def _position_window(self, win, acct, type_):
         """
